@@ -7,14 +7,18 @@ OC.L10N.register(
     "Date:" : "Дата:",
     "Where:" : "Дзе:",
     "Today" : "Сёння",
+    "Preview" : "Перадпрагляд",
     "Edit" : "Рэдагаваць",
     "Delete" : "Выдаліць",
     "Untitled calendar" : "Каляндар без назвы",
+    "Export" : "Экспарт",
     "Name" : "Назва",
     "Deleted" : "Выдалены",
     "Restore" : "Аднавіць",
     "Delete permanently" : "Выдаліць назаўжды",
     "Share link" : "Абагуліць спасылку",
+    "Copy public link" : "Скапіяваць публічную спасылку",
+    "No users or groups" : "Няма карыстальнікаў або груп",
     "Save" : "Захаваць",
     "Filename" : "Назва файла",
     "Cancel" : "Скасаваць",
@@ -28,7 +32,9 @@ OC.L10N.register(
     "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
     "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
     "Update" : "Абнавіць",
+    "Location" : "Месцазнаходжанне",
     "Description" : "Апісанне",
+    "Duration" : "Працягласць",
     "Add" : "Дадаць",
     "Monday" : "Панядзелак",
     "Tuesday" : "Аўторак",
@@ -44,10 +50,16 @@ OC.L10N.register(
     "Delete file" : "Выдаліць файл",
     "{attendee} ({role})" : "{attendee} ({role})",
     "Done" : "Гатова",
+    "Busy" : "Заняты",
     "Unknown" : "Невядомы",
     "Accept" : "Прыняць",
     "Decline" : "Адхіліць",
+    "Remove group" : "Выдаліць групу",
+    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
     "never" : "ніколі",
+    "Global" : "Глабальны",
+    "Public calendars" : "Публічныя календары",
+    "Invite" : "Запрасіць",
     "Close" : "Закрыць",
     "Daily" : "Штодня",
     "Weekly" : "Штотыдзень",
